RealtimeInpaintingSchema class

Constructors

RealtimeInpaintingSchema({required String key, String? webhook, String? trackId, required String prompt, required dynamic initImage, required dynamic maskImage, String? negativePrompt, double? strength, bool? base64, int? seed, int? guidanceScale, int? numInferenceSteps, int? width = 512, int? height = 512, int? samples = 1})
const
RealtimeInpaintingSchema.fromJson(Map<String, dynamic> json)
factory

Properties

base64 bool?
final
guidanceScale int?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
initImage → dynamic
final
key String
final
maskImage → dynamic
final
negativePrompt String?
final
numInferenceSteps int?
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samples int?
final
seed int?
final
strength double?
final
trackId String?
final
webhook String?
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited