Text2Video class

Constructors

Text2Video({required String key, String? webhook, String? trackId, required String modelId, required String prompt, String? negativePrompt, int? seed, int? width = 512, int? height = 512, int? numFrames = 30, int? numInferenceSteps = 50, double? guidanceScale = 7.5, int? fps = 8})
const
Text2Video.fromJson(Map<String, dynamic> json)
factory

Properties

fps int?
final
guidanceScale double?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
key String
final
modelId String
final
negativePrompt String?
final
numFrames int?
final
numInferenceSteps int?
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
final
trackId String?
final
webhook String?
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited