SpecificVideoSwap class
Constructors
- SpecificVideoSwap({required String apiKey, String? webhook, String? trackId, required dynamic initImage, required dynamic initVideo, required dynamic referenceImage, String? outputFormat = "mp4", bool? watermark})
-
const
-
SpecificVideoSwap.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initImage → dynamic
-
final
- initVideo → dynamic
-
final
- outputFormat → String?
-
final
- referenceImage → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackId → String?
-
final
- watermark → bool?
-
final
- webhook → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited