Text2VideoUltra class
Constructors
- Text2VideoUltra({required String key, String? webhook, String? trackId, required String prompt, String? negativePrompt, int? seed, String? resolution = "512x512", int? numFrames = 30, int? numInferenceSteps = 50, double? guidanceScale = 7.5, int? fps = 8, bool? portrait, int? sampleShift})
-
const
-
Text2VideoUltra.fromJson(Map<
String, dynamic> json) -
factory
Properties
- fps → int?
-
final
- guidanceScale → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- negativePrompt → String?
-
final
- numFrames → int?
-
final
- numInferenceSteps → int?
-
final
- portrait → bool?
-
final
- prompt → String
-
final
- resolution → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleShift → int?
-
final
- seed → int?
-
final
- trackId → String?
-
final
- webhook → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited